@@ -9,6 +9,11 @@ class RpcTimeout(Exception):
     pass
 
 
+class RpcConnectionError(Exception):
+    """Raised (in the caller) if the connection to the broker is lost while
+    waiting for an rpc reply"""
+
+
 class ContainerBeingKilled(Exception):
     """Raised by :meth:`Container.spawn_worker` if it has started a ``kill``
     sequence.
