@@ -1,3 +1,4 @@
+from nameko.events import Event
 from nameko.rpc import rpc
 
 
@@ -10,3 +11,7 @@ class ExampleService(object):
 
     def red_herring(self):
         pass
+
+
+class ExampleEvent(Event):
+    type = 'nameko_example_event'
