@@ -101,6 +101,13 @@ class ExampleService(object):
     def very_broken(self):
         raise AttributeError
 
+    @rpc
+    def call_async(self):
+        res1 = self.example_rpc.task_a.async()
+        res2 = self.example_rpc.task_b.async()
+        res3 = self.example_rpc.echo.async()
+        return [res2.result(), res1.result(), res3.result()]
+
     @rpc
     def call_unknown(self):
         return self.unknown_rpc.any_method()
@@ -401,6 +408,15 @@ def test_rpc_existing_method(container_factory, rabbit_config):
         assert proxy.task_b() == "result_b"
 
 
+def test_async_rpc(container_factory, rabbit_config):
+
+    container = container_factory(ExampleService, rabbit_config)
+    container.start()
+
+    with entrypoint_hook(container, 'call_async') as call_async:
+        assert call_async() == ["result_b", "result_a", [[], {}]]
+
+
 def test_rpc_incorrect_signature(container_factory, rabbit_config):
 
     class Service(object):
